@@ -265,7 +265,8 @@ gint
 main (gint argc,gchar *argv[])
 {
     gint i;
-    gboolean is_gtk_module = FALSE;
+    gchar **argv1;
+    char source[20] = "--display=:0.0";
 
 #ifdef ENABLE_NLS
     bindtextdomain (GETTEXT_PACKAGE, GNOPERNICUSLOCALEDIR);
@@ -275,26 +276,41 @@ main (gint argc,gchar *argv[])
 #endif
 #endif    
 
-    is_gtk_module = FALSE;
-    for (i = 0; i < argc; i++)
-	if (strncmp (argv[i], "--gtk-module", 12) == 0)
-	{
-	    is_gtk_module = TRUE;
-	    break;
-	}
-    
-    if (!is_gtk_module)
+    if (!gn_init_gconf ()) 
     {
-	gchar **argv1;
-
-	argv1 = g_new (gchar*, argc + 1);
-	for (i = 0; i < argc; i++)
-	    argv1[i] = argv[i];
-	argv1[argc] = "--gtk-module=gail:atk-bridge:gail-gnome";
-	argc++;
-	argv = argv1;
+        sru_warning (_("Gconf initialization failed."));
+	srcore_exit_all (TRUE);
+        return EXIT_FAILURE;
     }
 
+
+    argv1 = g_new (gchar*, argc + 2);
+    for (i = 0; i < argc; i++)
+	argv1[i] = argv[i];
+    argv1[argc] = "--gtk-module=gail:atk-bridge:gail-gnome";
+    argc++;
+
+    if (srcore_magnifier_status_get ())
+    {
+        gchar *path, *display;
+
+	path = g_strdup_printf ("%s/%s/%s", 
+			    CONFIG_PATH MAGNIFIER_PATH, 
+			    DEFAULT_MAGNIFIER_SCHEMA, 
+			     DEFAULT_MAGNIFIER_ID);
+	display = gnopiconf_get_string_from_section_with_default (path,
+				    MAGNIFIER_SOURCE, 		
+				    DEFAULT_MAGNIFIER_SOURCE);
+	if (display && magui_check_for_valid_screen (display))
+	    strcpy (source + 10, display);
+	g_free (path);
+        g_free (display);
+
+	argv1[argc] = source;
+	argc++;
+    }
+    argv = argv1;
+
     gnome_program_init ("gnopernicus", VERSION,
 			LIBGNOMEUI_MODULE,
 			argc, argv,
@@ -304,13 +320,10 @@ main (gint argc,gchar *argv[])
 			NULL);
     sru_log_init ();
 
-    if (!gn_init_gconf ()) 
-    {
-        sru_warning (_("Gconf initialization failed."));
-	srcore_exit_all (TRUE);
-        return EXIT_FAILURE;
-    }
-                        
+/* FIXME the next line will be available only starting with gtk+ 2.6 */
+    /* gtk_window_set_default_icon_name ("gnopernicus"); */
+    gtk_window_set_default_icon_from_file (GNOPERNICUS_ICON, NULL);
+
     if (!gn_run_with_parameters ())
     {
 	sru_warning (_("Invalid parameters."));
@@ -373,8 +386,7 @@ main (gint argc,gchar *argv[])
 
     sru_log_terminate ();
     
-    if (!is_gtk_module)
-    	g_free (argv);
+    g_free (argv1);
     
     return EXIT_SUCCESS;
 }
