@@ -1761,6 +1761,42 @@ srl_set_checked_info (Accessible *acc,
     return TRUE;
 }
 
+
+static AccessibleText*
+srl_get_acc_text_from_children (Accessible *acc)
+{
+    gint i, cnt;
+    AccessibleText *rv = NULL;
+
+    srl_assert (acc);
+
+    cnt = Accessible_getChildCount (acc);
+    for (i = 0; i < cnt; i++)
+    {
+	Accessible *child = Accessible_getChildAtIndex (acc, i);
+	if (!child)
+	    continue;
+	if (Accessible_getRole (child) == SPI_ROLE_TEXT)
+	    rv = Accessible_getText (child);
+	Accessible_unref (child);
+	if (rv)
+	    return rv;
+    }
+    for (i = 0; i < cnt; i++)
+    {
+	Accessible *child = Accessible_getChildAtIndex (acc, i);
+	if (!child)
+	    continue;
+	rv = srl_get_acc_text_from_children (child);
+	Accessible_unref (child);
+	if (rv)
+	    return rv;
+    }
+    
+
+    return NULL;
+}
+
 static gboolean
 srl_set_info (Accessible *acc,
 	      SRLLastInfo *info)
@@ -1778,6 +1814,8 @@ srl_set_info (Accessible *acc,
     }
 
     text = Accessible_getText (acc);
+    if (!text && Accessible_getRole (acc) == SPI_ROLE_COMBO_BOX)
+    	text = srl_get_acc_text_from_children (acc);
     if (text)
     {
         srl_set_text_info (text, info);
