@@ -883,7 +883,7 @@ srw_text_chunk_from_accessible (Accessible	*accessible,
 				{	
 				    if (string)
 					g_free (string);
-				    string = g_strdup ("------");
+				    string = g_strdup ("");
 				}
 			}
                         /* use name instead if there is no text available*/
@@ -2318,8 +2318,8 @@ srw_elements_from_accessible (Accessible 	*accessible,
 					{
 					    cnt = strlen (text_chunk->string);   
 					    for (i = 0; i < cnt; i++)
-						if ((guint16)*(text_chunk->string + i) != 0x20 &&
-					    	    (guint16)*(text_chunk->string + i) != 0x160)   
+						if (text_chunk->string[i] != 0x20 &&
+					    	    (text_chunk->string[i] != 0x01 && text_chunk->string[i+1] != 0x60))
 						{
 						    only_spaces = FALSE;
 						    break;
